==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/sr/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "овог квартала",
	"field-quarter-short-relative+1": "следећег квартала",
	"field-tue-relative+-1": "прошлог уторка",
	"field-year": "година",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "у среду",
	"field-wed-relative+1": "следеће среде",
	"dateFormatItem-ms": "mm.ss",
	"field-minute": "минут",
	"field-tue-narrow-relative+0": "у уто",
	"field-tue-narrow-relative+1": "следећег уто",
	"field-thu-short-relative+0": "у чет",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "следећег чет",
	"field-day-relative+0": "данас",
	"field-day-relative+1": "сутра",
	"field-day-relative+2": "прекосутра",
	"field-wed-narrow-relative+-1": "прошле сре",
	"field-year-narrow": "г.",
	"field-tue-relative+0": "у уторак",
	"field-tue-relative+1": "следећег уторка",
	"field-second-short": "сек.",
	"dateFormatItem-yyyyMM": "MM.y. G",
	"dateFormatItem-MMMd": "d. MMM",
	"field-week-relative+0": "ове недеље",
	"field-month-relative+0": "овог месеца",
	"field-week-relative+1": "следеће недеље",
	"field-month-relative+1": "следећег месеца",
	"field-sun-narrow-relative+0": "у нед",
	"field-mon-short-relative+0": "у пон",
	"field-sun-narrow-relative+1": "следеће нед",
	"field-mon-short-relative+1": "следећег пон",
	"field-second-relative+0": "сада",
	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
	"field-month-short": "мес.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-yyyyMd": "d.M.y. GGGGG",
	"field-day": "дан",
	"field-year-relative+-1": "прошле године",
	"field-sat-short-relative+-1": "прошле суб",
	"field-hour-relative+0": "овог сата",
	"dateFormatItem-yyyyMEd": "E, d.M.y. GGGGG",
	"field-wed-relative+-1": "прошле среде",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "прошле суб",
	"field-second": "секунд",
	"dateFormat-long": "d. MMMM y. G",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-quarter": "квартал",
	"dateFormatItem-yyyyMMdd": "dd.MM.y. G",
	"field-week-short": "нед.",
	"field-tue-short-relative+0": "у уто",
	"field-tue-short-relative+1": "следећег уто",
	"field-mon-relative+-1": "прошлог понедељка",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-month": "месец",
	"field-day-narrow": "д.",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "мин.",
	"field-dayperiod": "пре подне/по подне",
	"field-sat-short-relative+0": "у суб",
	"field-sat-short-relative+1": "следеће суб",
	"dateFormat-medium": "d.MM.y. G",
	"dateFormatItem-yyyyMMMM": "MMMM y. G",
	"dateFormatItem-yyyyM": "M.y. GGGGG",
	"field-second-narrow": "с.",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"field-year-short": "год.",
	"field-quarter-relative+-1": "прошлог квартала",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"field-sat-relative+-1": "прошле суботе",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "сат",
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"field-month-relative+-1": "прошлог месеца",
	"dateFormatItem-MMMdd": "dd.MMM",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "кв.",
	"field-sat-narrow-relative+0": "у суб",
	"field-fri-relative+0": "у петак",
	"field-sat-narrow-relative+1": "следеће суб",
	"field-fri-relative+1": "следећег петка",
	"field-sun-short-relative+0": "у нед",
	"field-sun-short-relative+1": "следеће нед",
	"field-week-relative+-1": "прошле недеље",
	"field-quarter-short-relative+-1": "прошлог квартала",
	"field-quarter-relative+0": "овог квартала",
	"field-minute-relative+0": "овог минута",
	"field-quarter-relative+1": "следећег квартала",
	"field-wed-short-relative+-1": "прошле сре",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-thu-short-relative+-1": "прошлог чет",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"field-mon-narrow-relative+-1": "прошлог пон",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "прошлог чет",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "прошлог уто",
	"dateFormatItem-H": "HH",
	"dateFormatItem-yyyy": "y. G",
	"field-wed-short-relative+0": "у сре",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "следеће сре",
	"field-sun-relative+-1": "прошле недеље",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "hh.mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "дан у недељи",
	"field-quarter-narrow-relative+0": "овог квартала",
	"field-sat-relative+0": "у суботу",
	"field-quarter-narrow-relative+1": "следећег квартала",
	"dateFormatItem-h": "hh a",
	"field-sat-relative+1": "следеће суботе",
	"dateFormatItem-MEd": "E, d.M.",
	"dateFormatItem-y": "y. G",
	"field-thu-narrow-relative+0": "у чет",
	"field-thu-narrow-relative+1": "следећег чет",
	"field-sun-narrow-relative+-1": "прошле нед",
	"field-mon-short-relative+-1": "прошлог пон",
	"field-thu-relative+0": "у четвртак",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-hms": "hh.mm.ss a",
	"field-fri-short-relative+-1": "прошлог пет",
	"field-thu-relative+-1": "прошлог четвртка",
	"field-week": "недеља",
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "у сре",
	"field-wed-narrow-relative+1": "следеће сре",
	"field-quarter-narrow-relative+-1": "прошлог квартала",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"field-fri-short-relative+0": "у пет",
	"field-fri-short-relative+1": "следећег пет",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"field-hour-short": "ч.",
	"field-month-narrow": "м.",
	"field-hour-narrow": "ч.",
	"field-fri-narrow-relative+-1": "прошлог пет",
	"field-year-relative+0": "ове године",
	"field-year-relative+1": "следеће године",
	"field-fri-relative+-1": "прошлог петка",
	"field-tue-short-relative+-1": "прошлог уто",
	"field-minute-narrow": "мин.",
	"field-mon-narrow-relative+0": "у пон",
	"field-mon-narrow-relative+1": "следећег пон",
	"field-zone": "временска зона",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-quarter-narrow": "кв.",
	"field-sun-short-relative+-1": "прошле нед",
	"field-day-relative+-1": "јуче",
	"field-day-relative+-2": "прекјуче",
	"field-sun-relative+0": "у недељу",
	"dateFormatItem-MMdd": "MM-dd",
	"field-sun-relative+1": "следеће недеље",
	"dateFormatItem-Gy": "y. G",
	"field-day-short": "д.",
	"field-week-narrow": "н.",
	"field-era": "ера",
	"field-fri-narrow-relative+0": "у пет",
	"field-fri-narrow-relative+1": "следећег пет"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/sr/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "овог квартала",
	"field-quarter-short-relative+1": "следећег квартала",
	"field-tue-relative+-1": "прошлог уторка",
	"field-year": "година",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "у среду",
	"field-wed-relative+1": "следеће среде",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "минут",
	"field-month-narrow-relative+-1": "прошлог м.",
	"field-tue-narrow-relative+0": "у уто",
	"field-tue-narrow-relative+1": "следећег уто",
	"field-day-short-relative+-1": "јуче",
	"field-thu-short-relative+0": "у чет",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "данас",
	"field-day-short-relative+-2": "прекјуче",
	"field-thu-short-relative+1": "следећег чет",
	"field-day-relative+1": "сутра",
	"field-week-narrow-relative+0": "ове н.",
	"field-day-relative+2": "прекосутра",
	"field-week-narrow-relative+1": "следеће н.",
	"dateFormatItem-EBhms": "E hh:mm:ss B",
	"field-wed-narrow-relative+-1": "прошле сре",
	"field-year-narrow": "г.",
	"field-era-short": "ера",
	"field-year-narrow-relative+0": "ове г.",
	"field-tue-relative+0": "у уторак",
	"field-year-narrow-relative+1": "следеће г.",
	"field-tue-relative+1": "следећег уторка",
	"field-weekdayOfMonth": "дан у месецу",
	"field-second-short": "сек.",
	"dateFormatItem-yyyyMM": "MM.y. G",
	"dateFormatItem-MMMd": "d. MMM",
	"field-weekdayOfMonth-narrow": "дан у месецу",
	"field-week-relative+0": "ове недеље",
	"field-month-relative+0": "овог месеца",
	"field-week-relative+1": "следеће недеље",
	"field-month-relative+1": "следећег месеца",
	"field-sun-narrow-relative+0": "у нед",
	"field-mon-short-relative+0": "у пон",
	"field-sun-narrow-relative+1": "сл. нед.",
	"field-mon-short-relative+1": "следећег пон",
	"field-second-relative+0": "сада",
	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
	"field-weekOfMonth": "недеља у месецу",
	"field-month-short": "мес.",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-yyyyMd": "d.M.y. GGGGG",
	"field-day": "дан",
	"field-dayOfYear-short": "дан у год.",
	"field-year-relative+-1": "прошле године",
	"field-sat-short-relative+-1": "прошле суб",
	"field-hour-relative+0": "овог сата",
	"dateFormatItem-yyyyMEd": "E, d.M.y. GGGGG",
	"field-wed-relative+-1": "прошле среде",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "прошле суб",
	"field-second": "секунд",
	"dateFormatItem-Ehms": "E hh:mm:ss a",
	"dateFormat-long": "d. MMMM y. G",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-quarter": "квартал",
	"dateFormatItem-yyyyMMdd": "dd.MM.y. G",
	"field-week-short": "нед.",
	"field-day-narrow-relative+0": "данас",
	"field-day-narrow-relative+1": "сутра",
	"field-day-narrow-relative+2": "прекосутра",
	"field-tue-short-relative+0": "у уто",
	"field-tue-short-relative+1": "следећег уто",
	"field-month-short-relative+-1": "прошлог мес.",
	"field-mon-relative+-1": "прошлог понедељка",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-month": "месец",
	"field-day-narrow": "д.",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "мин.",
	"field-dayperiod": "пре подне/по подне",
	"field-sat-short-relative+0": "у суб",
	"field-sat-short-relative+1": "следеће суб",
	"dateFormat-medium": "d.MM.y. G",
	"dateFormatItem-yyyyMMMM": "MMMM y. G",
	"dateFormatItem-yyyyM": "M.y. GGGGG",
	"field-second-narrow": "с.",
	"field-mon-relative+0": "у понедељак",
	"field-day-narrow-relative+-1": "јуче",
	"field-year-short": "год.",
	"field-mon-relative+1": "следећег понедељка",
	"field-day-narrow-relative+-2": "прекјуче",
	"field-quarter-relative+-1": "прошлог квартала",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"field-dayperiod-narrow": "пре подне/по подне",
	"field-week-narrow-relative+-1": "прошле н.",
	"field-dayOfYear": "дан у години",
	"field-sat-relative+-1": "прошле суботе",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d.M.",
	"field-hour": "сат",
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"field-month-relative+-1": "прошлог месеца",
	"dateFormatItem-MMMdd": "dd.MMM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "кв.",
	"field-sat-narrow-relative+0": "у суб",
	"field-fri-relative+0": "у петак",
	"field-sat-narrow-relative+1": "следеће суб",
	"field-fri-relative+1": "следећег петка",
	"dateFormatItem-EBhm": "E hh:mm B",
	"field-month-narrow-relative+0": "овог м.",
	"field-month-narrow-relative+1": "следећег м.",
	"field-sun-short-relative+0": "у нед",
	"field-sun-short-relative+1": "сл. нед.",
	"field-week-relative+-1": "прошле недеље",
	"field-quarter-short-relative+-1": "прошлог квартала",
	"dateFormatItem-Ehm": "E hh:mm a",
	"field-quarter-relative+0": "овог квартала",
	"field-minute-relative+0": "овог минута",
	"field-quarter-relative+1": "следећег квартала",
	"field-wed-short-relative+-1": "прошле сре",
	"dateFormat-short": "d.M.y. GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "прошле г.",
	"field-thu-short-relative+-1": "прошлог чет",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"field-mon-narrow-relative+-1": "прошлог пон",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "прошлог чет",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "нед. у мес.",
	"field-tue-narrow-relative+-1": "прошлог уто",
	"dateFormatItem-yyyy": "y. G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "у сре",
	"field-wed-short-relative+1": "следеће сре",
	"field-sun-relative+-1": "прошле недеље",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "дан у недељи",
	"field-day-short-relative+0": "данас",
	"field-quarter-narrow-relative+0": "овог квартала",
	"field-day-short-relative+1": "сутра",
	"field-sat-relative+0": "у суботу",
	"field-quarter-narrow-relative+1": "следећег квартала",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "прекосутра",
	"field-sat-relative+1": "следеће суботе",
	"field-week-short-relative+0": "ове нед.",
	"field-week-short-relative+1": "следеће нед.",
	"field-dayOfYear-narrow": "дан у год.",
	"field-month-short-relative+0": "овог мес.",
	"field-month-short-relative+1": "следећег мес.",
	"field-weekdayOfMonth-short": "дан у месецу",
	"dateFormatItem-MEd": "E, d.M.",
	"field-zone-narrow": "временска зона",
	"dateFormatItem-y": "y. G",
	"field-thu-narrow-relative+0": "у чет",
	"field-sun-narrow-relative+-1": "пр. нед.",
	"field-mon-short-relative+-1": "прошлог пон",
	"field-thu-narrow-relative+1": "следећег чет",
	"field-thu-relative+0": "у четвртак",
	"field-thu-relative+1": "следећег четвртка",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-fri-short-relative+-1": "прошлог пет",
	"field-thu-relative+-1": "прошлог четвртка",
	"field-week": "недеља",
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "у сре",
	"field-wed-narrow-relative+1": "следеће сре",
	"field-quarter-narrow-relative+-1": "прошлог квартала",
	"field-year-short-relative+0": "ове год.",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"field-dayperiod-short": "пре подне/по подне",
	"field-year-short-relative+1": "следеће год.",
	"field-fri-short-relative+0": "у пет",
	"field-fri-short-relative+1": "следећег пет",
	"field-week-short-relative+-1": "прошле нед.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"field-hour-short": "ч.",
	"field-zone-short": "временска зона",
	"field-month-narrow": "м.",
	"field-hour-narrow": "ч.",
	"field-fri-narrow-relative+-1": "прошлог пет",
	"field-year-relative+0": "ове године",
	"field-year-relative+1": "следеће године",
	"field-era-narrow": "ера",
	"field-fri-relative+-1": "прошлог петка",
	"dateFormatItem-Bhms": "hh:mm:ss B",
	"field-tue-short-relative+-1": "прошлог уто",
	"field-minute-narrow": "мин.",
	"field-mon-narrow-relative+0": "у пон",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "следећег пон",
	"field-year-short-relative+-1": "прошле год.",
	"field-zone": "временска зона",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-weekOfMonth-narrow": "нед. у мес.",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "дан у недељи",
	"field-quarter-narrow": "кв.",
	"field-sun-short-relative+-1": "пр. нед.",
	"field-day-relative+-1": "јуче",
	"field-day-relative+-2": "прекјуче",
	"field-weekday-short": "дан у недељи",
	"dateFormatItem-Bhm": "hh:mm B",
	"field-sun-relative+0": "у недељу",
	"dateFormatItem-MMdd": "MM-dd",
	"field-sun-relative+1": "следеће недеље",
	"dateFormatItem-Gy": "y. G",
	"field-day-short": "д.",
	"field-week-narrow": "н.",
	"field-era": "ера",
	"field-fri-narrow-relative+0": "у пет",
	"field-fri-narrow-relative+1": "следећег пет"
}
//end v1.x content
);
